﻿using Antlr4.Runtime;
using Antlr4.Runtime.Atn;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace AntlrPerformanceDifference
{
    public class Program
    {
        public static void Main(string[] args)
        {
            DoFast();
            DoSlow();

            Console.ReadKey();
        }

        private static void DoFast()
        {
            Stopwatch sw = Stopwatch.StartNew();

            var sourceCode = File.ReadAllText("File.txt");
            var input = new Antlr4.Runtime.AntlrInputStream(sourceCode);
            var lexer = new FastLexer(input);
            var ts = new CommonTokenStream(lexer);
            var parser = new FastParser(ts);

            //parser.Interpreter.enable_global_context_dfa = true;
            //parser.Interpreter.force_global_context = true;
            //parser.Interpreter.treat_sllk1_conflict_as_ambiguity = true;
            //parser.Interpreter.tail_call_preserves_sll = true;
            parser.Interpreter.PredictionMode = PredictionMode.Sll;

            parser.cobol_program();

            Console.WriteLine(sw.ElapsedMilliseconds);
            Console.WriteLine("DONE - FAST");
        }
        private static void DoSlow()
        {
            Stopwatch sw = Stopwatch.StartNew();

            var sourceCode = File.ReadAllText("File.txt");
            var input = new Antlr4.Runtime.AntlrInputStream(sourceCode);
            var lexer = new SlowLexer(input);
            var ts = new CommonTokenStream(lexer);
            var parser = new SlowParser(ts);

            //parser.Interpreter.enable_global_context_dfa = true;
            //parser.Interpreter.force_global_context = true;
            //parser.Interpreter.treat_sllk1_conflict_as_ambiguity = true;
            //parser.Interpreter.tail_call_preserves_sll = true;
            parser.Interpreter.PredictionMode = PredictionMode.Sll;

            parser.cobol_program();

            Console.WriteLine(sw.ElapsedMilliseconds);
            Console.WriteLine("DONE - SLOW");
        }
    }
}
